==> webkitgtk-2.14.0.tar.xz: webkitgtk-2.14.0/Source/WebCore/rendering/RenderingAllInOne.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

// This all-in-one cpp file cuts down on template bloat to allow us to build our Windows release build.

#include "AutoTableLayout.cpp"
#include "BidiRun.cpp"
#include "BorderEdge.cpp"
#include "BreakLines.cpp"
#include "ClipRect.cpp"
#include "CounterNode.cpp"
#include "EllipsisBox.cpp"
#include "FilterEffectRenderer.cpp"
#include "FixedTableLayout.cpp"
#include "FloatingObjects.cpp"
#include "FlowThreadController.cpp"
#include "HitTestLocation.cpp"
#include "HitTestResult.cpp"
#include "HitTestingTransformState.cpp"
#include "ImageQualityController.cpp"
#include "InlineBox.cpp"
#include "InlineElementBox.cpp"
#include "InlineFlowBox.cpp"
#include "InlineIterator.cpp"
#include "InlineTextBox.cpp"
#include "LayoutRepainter.cpp"
#include "LayoutState.cpp"
#include "OrderIterator.cpp"
#include "PointerEventsHitRules.cpp"
#include "RenderAttachment.cpp"
#include "RenderBlock.cpp"
#include "RenderBlockFlow.cpp"
#include "RenderBlockLineLayout.cpp"
#include "RenderBox.cpp"
#include "RenderBoxModelObject.cpp"
#include "RenderButton.cpp"
#include "RenderCombineText.cpp"
#include "RenderCounter.cpp"
#include "RenderDeprecatedFlexibleBox.cpp"
#include "RenderDetailsMarker.cpp"
#include "RenderElement.cpp"
#include "RenderEmbeddedObject.cpp"
#include "RenderFieldset.cpp"
#include "RenderFileUploadControl.cpp"
#include "RenderFlexibleBox.cpp"
#include "RenderFlowThread.cpp"
#include "RenderFrame.cpp"
#include "RenderFrameBase.cpp"
#include "RenderFrameSet.cpp"
#include "RenderFullScreen.cpp"
#include "RenderGeometryMap.cpp"
#include "RenderGrid.cpp"
#include "RenderHTMLCanvas.cpp"
#include "RenderIFrame.cpp"
#include "RenderImage.cpp"
#include "RenderImageResource.cpp"
#include "RenderImageResourceStyleImage.cpp"
#include "RenderInline.cpp"
#include "RenderLayer.cpp"
#include "RenderLayerBacking.cpp"
#include "RenderLayerCompositor.cpp"
#include "RenderLayerFilterInfo.cpp"
#include "RenderLayerModelObject.cpp"
#include "RenderLineBoxList.cpp"
#include "RenderLineBreak.cpp"
#include "RenderListBox.cpp"
#include "RenderListItem.cpp"
#include "RenderListMarker.cpp"
#include "RenderMarquee.cpp"
#include "RenderMedia.cpp"
#include "RenderMediaControlElements.cpp"
#include "RenderMediaControls.cpp"
#include "RenderMenuList.cpp"
#include "RenderMeter.cpp"
#include "RenderMultiColumnFlowThread.cpp"
#include "RenderMultiColumnSet.cpp"
#include "RenderMultiColumnSpannerPlaceholder.cpp"
#include "RenderNamedFlowFragment.cpp"
#include "RenderNamedFlowThread.cpp"
#include "RenderObject.cpp"
#include "RenderProgress.cpp"
#include "RenderQuote.cpp"
#include "RenderRegion.cpp"
#include "RenderRegionSet.cpp"
#include "RenderReplaced.cpp"
#include "RenderReplica.cpp"
#include "RenderRuby.cpp"
#include "RenderRubyBase.cpp"
#include "RenderRubyRun.cpp"
#include "RenderRubyText.cpp"
#include "RenderScrollbar.cpp"
#include "RenderScrollbarPart.cpp"
#include "RenderScrollbarTheme.cpp"
#include "RenderSearchField.cpp"
#include "RenderSelectionInfo.cpp"
#include "RenderSlider.cpp"
#include "RenderSnapshottedPlugIn.cpp"
#include "RenderTable.cpp"
#include "RenderTableCaption.cpp"
#include "RenderTableCell.cpp"
#include "RenderTableCol.cpp"
#include "RenderTableRow.cpp"
#include "RenderTableSection.cpp"
#include "RenderText.cpp"
#include "RenderTextControl.cpp"
#include "RenderTextControlMultiLine.cpp"
#include "RenderTextControlSingleLine.cpp"
#include "RenderTextFragment.cpp"
#include "RenderTextLineBoxes.cpp"
#include "RenderTheme.cpp"
#if PLATFORM(WIN)
#include "RenderThemeWin.cpp"
#endif
#include "RenderTreeAsText.cpp"
#include "RenderVTTCue.cpp"
#include "RenderVideo.cpp"
#include "RenderView.cpp"
#include "RenderWidget.cpp"
#include "RootInlineBox.cpp"
#include "ScrollBehavior.cpp"
#include "SelectionSubtreeRoot.cpp"
#include "SimpleLineLayout.cpp"
#include "SimpleLineLayoutFlowContents.cpp"
#include "SimpleLineLayoutFunctions.cpp"
#include "SimpleLineLayoutResolver.cpp"
#include "SimpleLineLayoutTextFragmentIterator.cpp"
#include "TextAutosizer.cpp"
#include "TextDecorationPainter.cpp"
#include "TextPaintStyle.cpp"
#include "TextPainter.cpp"

==> webkitgtk-2.16.4.tar.xz: webkitgtk-2.16.4/Source/WebCore/rendering/RenderingAllInOne.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

// This all-in-one cpp file cuts down on template bloat to allow us to build our Windows release build.

#include "AutoTableLayout.cpp"
#include "BidiRun.cpp"
#include "BorderEdge.cpp"
#include "BreakLines.cpp"
#include "ClipRect.cpp"
#include "CounterNode.cpp"
#include "EllipsisBox.cpp"
#include "FilterEffectRenderer.cpp"
#include "FixedTableLayout.cpp"
#include "FloatingObjects.cpp"
#include "FlowThreadController.cpp"
#include "HitTestLocation.cpp"
#include "HitTestResult.cpp"
#include "HitTestingTransformState.cpp"
#include "ImageQualityController.cpp"
#include "InlineBox.cpp"
#include "InlineElementBox.cpp"
#include "InlineFlowBox.cpp"
#include "InlineIterator.cpp"
#include "InlineTextBox.cpp"
#include "LayoutRepainter.cpp"
#include "LayoutState.cpp"
#include "OrderIterator.cpp"
#include "PointerEventsHitRules.cpp"
#include "RenderAttachment.cpp"
#include "RenderBlock.cpp"
#include "RenderBlockFlow.cpp"
#include "RenderBlockLineLayout.cpp"
#include "RenderBox.cpp"
#include "RenderBoxModelObject.cpp"
#include "RenderButton.cpp"
#include "RenderCombineText.cpp"
#include "RenderCounter.cpp"
#include "RenderDeprecatedFlexibleBox.cpp"
#include "RenderDetailsMarker.cpp"
#include "RenderElement.cpp"
#include "RenderEmbeddedObject.cpp"
#include "RenderFieldset.cpp"
#include "RenderFileUploadControl.cpp"
#include "RenderFlexibleBox.cpp"
#include "RenderFlowThread.cpp"
#include "RenderFrame.cpp"
#include "RenderFrameBase.cpp"
#include "RenderFrameSet.cpp"
#include "RenderFullScreen.cpp"
#include "RenderGeometryMap.cpp"
#include "RenderGrid.cpp"
#include "RenderHTMLCanvas.cpp"
#include "RenderIFrame.cpp"
#include "RenderImage.cpp"
#include "RenderImageResource.cpp"
#include "RenderImageResourceStyleImage.cpp"
#include "RenderInline.cpp"
#include "RenderLayer.cpp"
#include "RenderLayerBacking.cpp"
#include "RenderLayerCompositor.cpp"
#include "RenderLayerFilterInfo.cpp"
#include "RenderLayerModelObject.cpp"
#include "RenderLineBoxList.cpp"
#include "RenderLineBreak.cpp"
#include "RenderListBox.cpp"
#include "RenderListItem.cpp"
#include "RenderListMarker.cpp"
#include "RenderMarquee.cpp"
#include "RenderMedia.cpp"
#include "RenderMediaControlElements.cpp"
#include "RenderMediaControls.cpp"
#include "RenderMenuList.cpp"
#include "RenderMeter.cpp"
#include "RenderMultiColumnFlowThread.cpp"
#include "RenderMultiColumnSet.cpp"
#include "RenderMultiColumnSpannerPlaceholder.cpp"
#include "RenderNamedFlowFragment.cpp"
#include "RenderNamedFlowThread.cpp"
#include "RenderObject.cpp"
#include "RenderProgress.cpp"
#include "RenderQuote.cpp"
#include "RenderRegion.cpp"
#include "RenderRegionSet.cpp"
#include "RenderReplaced.cpp"
#include "RenderReplica.cpp"
#include "RenderRuby.cpp"
#include "RenderRubyBase.cpp"
#include "RenderRubyRun.cpp"
#include "RenderRubyText.cpp"
#include "RenderScrollbar.cpp"
#include "RenderScrollbarPart.cpp"
#include "RenderScrollbarTheme.cpp"
#include "RenderSearchField.cpp"
#include "RenderSelectionInfo.cpp"
#include "RenderSlider.cpp"
#include "RenderSnapshottedPlugIn.cpp"
#include "RenderTable.cpp"
#include "RenderTableCaption.cpp"
#include "RenderTableCell.cpp"
#include "RenderTableCol.cpp"
#include "RenderTableRow.cpp"
#include "RenderTableSection.cpp"
#include "RenderText.cpp"
#include "RenderTextControl.cpp"
#include "RenderTextControlMultiLine.cpp"
#include "RenderTextControlSingleLine.cpp"
#include "RenderTextFragment.cpp"
#include "RenderTextLineBoxes.cpp"
#include "RenderTheme.cpp"
#if PLATFORM(WIN)
#include "RenderThemeWin.cpp"
#endif
#include "RenderTreeAsText.cpp"
#include "RenderVTTCue.cpp"
#include "RenderVideo.cpp"
#include "RenderView.cpp"
#include "RenderWidget.cpp"
#include "RootInlineBox.cpp"
#include "ScrollAlignment.cpp"
#include "SelectionSubtreeRoot.cpp"
#include "SimpleLineLayout.cpp"
#include "SimpleLineLayoutCoverage.cpp"
#include "SimpleLineLayoutFlowContents.cpp"
#include "SimpleLineLayoutFunctions.cpp"
#include "SimpleLineLayoutPagination.cpp"
#include "SimpleLineLayoutResolver.cpp"
#include "SimpleLineLayoutTextFragmentIterator.cpp"
#include "TextDecorationPainter.cpp"
#include "TextPaintStyle.cpp"
#include "TextPainter.cpp"
